//-----------------------------------------------------------------
// Licensed Materials - Property of IBM
//
// WebSphere Commerce
//
// (C) Copyright IBM Corp. 2016 All Rights Reserved.
//
// US Government Users Restricted Rights - Use, duplication or
// disclosure restricted by GSA ADP Schedule Contract with
// IBM Corp.
//-----------------------------------------------------------------

module.exports = function( grunt ) {
	"use strict";

	grunt.initConfig( {
		pkg: grunt.file.readJSON( "package.json" ),

		// --------------- Destination -----------------------
		webContentDir: "../..",
		widgetsSourceDir: "<%= webContentDir %>/Widgets_801",
		widgetsJSDistFileName: "homepage_widgets",

		concat: {
			options: {
				separator: ';',
			},
			widgets: {
				// wc jquery extension
				src: [
					// widget files
					"<%= widgetsSourceDir %>/com.ibm.commerce.store.widgets.GlobalLogin/javascript/*.js"
				],
				dest: "<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.uncompressed.js"				 
			}
		},

		copy: {
			dev: {
				files: [
					{
						// widgets.js
						src: "<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.uncompressed.js",
						dest: "<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.js"
					}
				]
			}
		},

		clean: {
			files: [
				"<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.uncompressed.js",
				"<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.js",
				"<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.map"
			],
			options: {
				force: true
			}
		},

		watch: {
			widgets: {
				files: [ "<%= concat.widgets.src %>" ],
				tasks: [ "concat:widgets", "copy:dev" ]
			}
		},

		uglify: {
			widgets: {
				files: {
					"<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.js":
						"<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.uncompressed.js"
				},
				options: {
					preserveComments: false,
					sourceMap: true,
					sourceMapName:
						"<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.map",
					report: "min",
					beautify: {
						"ascii_only": true
					},
					compress: {
						"hoist_funs": false,
						loops: false,
						unused: false
					}
				}
			}
		}
	} );

	// Integrate jQuery specific tasks
	grunt.loadNpmTasks('grunt-contrib-copy');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-clean');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-contrib-watch');

	// Short list as a high frequency watch task
	grunt.registerTask( "dev", [ "clean", "concat", "copy:dev" ] );

	//grunt.registerTask( "prod", [ "clean", "build:*:*", "uglify", "remove_map_comment", "dist:*" ] );
	grunt.registerTask( "prod", [ "clean", "concat", "uglify" ] );

	// default option
	grunt.registerTask( "default", [ "dev", "watch" ] );
};
