//-----------------------------------------------------------------
// Licensed Materials - Property of IBM
//
// WebSphere Commerce
//
// (C) Copyright IBM Corp. 2016 All Rights Reserved.
//
// US Government Users Restricted Rights - Use, duplication or
// disclosure restricted by GSA ADP Schedule Contract with
// IBM Corp.
//-----------------------------------------------------------------

module.exports = function( grunt ) {
	"use strict";

	grunt.initConfig( {
		pkg: grunt.file.readJSON( "package.json" ),

		// --------------- Destination -----------------------
		webContentDir: "../..",
		storeSourceDir: "<%= webContentDir %>/<%= grunt.option('storename') %>",
		distDir: "<%= storeSourceDir %>/javascript",
		storeJsDistFileName: "homepage_store",
		properties: {
			gruntProps: 'grunt.properties'
		},

		concat: {
			options: {
				separator: ';',
			},
			storejs: {
				src: [
					// store JS files
					"<%= storeSourceDir %>/javascript/Common/ShoppingActions.js",
					"<%= storeSourceDir %>/javascript/Common/ShoppingActionsServicesDeclaration.js",
					"<%= storeSourceDir %>/javascript/StoreCommonUtilities.js",
					"<%= storeSourceDir %>/javascript/MessageHelper.js",
					"<%= storeSourceDir %>/javascript/Widgets/Search.js",
					"<%= storeSourceDir %>/javascript/Widgets/header.js",
					"<%= storeSourceDir %>/javascript/Widgets/MiniShopCartDisplay/MiniShopCartDisplay.js"
				],
				dest: "<%= distDir %>/<%= storeJsDistFileName %>.uncompressed.js"
			}
		},

		copy: {
			devStore: {
				files: [
					{
						// store.js
						src: "<%= distDir %>/<%= storeJsDistFileName %>.uncompressed.js",
						dest: "<%= distDir %>/<%= storeJsDistFileName %>.js"
					}
				]
			},
			
			prod: {
				files: [
					{
						// from owl carousel
						src: "<%= vendorSourceDir %>/OwlCarousel/owl-carousel/grabbing.png",
						dest: "<%= storeSourceDir %>/css/grabbing.png"
					}
				]
			}
		},

		clean: {
			files: [
				"<%= distDir %>/<%= storeJsDistFileName %>.uncompressed.js",
				"<%= distDir %>/<%= storeJsDistFileName %>.js",
				"<%= distDir %>/<%= storeJsDistFileName %>.map"
			],
			options: {
				force: true
			}
		},

		watch: {
			storejs: {
				files: [ "<%= concat.storejs.src %>" ],
				tasks: [ "concat:storejs", "copy:devStore" ]
			}
		},

		uglify: {
			storejs: {
				files: {
					"<%= distDir %>/<%= storeJsDistFileName %>.js":
					"<%= distDir %>/<%= storeJsDistFileName %>.uncompressed.js"
				},
				options: {
					preserveComments: false,
					sourceMap: true,
					sourceMapName:
						"<%= distDir %>/<%= storeJsDistFileName %>.map",
					report: "min",
					beautify: {
						"ascii_only": true
					},
					compress: {
						"hoist_funs": false,
						loops: false,
						unused: false
					}
				}
			}
		}
	} );

	// Integrate jQuery specific tasks
	grunt.loadNpmTasks('grunt-contrib-copy');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-clean');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-contrib-watch');
	grunt.loadNpmTasks('grunt-contrib-cssmin');
	grunt.loadNpmTasks('grunt-properties-reader');

	// Check if storename is provided
	grunt.registerTask( "check_store", function() {
		// make sure storename param exists
		if ( grunt.option( "storename" ) == null ) {
			grunt.fail.fatal( "storename param is mandatory", [ 3 ] );
		}
		
		var path = __dirname + "/../../" + grunt.option( "storename" );
		if (!grunt.file.exists(path)) {
			grunt.fail.fatal( "cannot find directory: " + path, [ 3 ] );
		}
	} );
	
	// Short list as a high frequency watch task
	grunt.registerTask( "dev", [ "properties", "check_store", "clean", "concat", "copy:devStore" ] );

	//grunt.registerTask( "prod", [ "clean", "build:*:*", "uglify", "remove_map_comment", "dist:*" ] );
	grunt.registerTask( "prod", [ "properties", "check_store", "clean", "concat", "uglify", "copy:prod" ] );

	// default option
	grunt.registerTask( "default", [ "dev", "watch" ] );
};
