//-----------------------------------------------------------------
// Licensed Materials - Property of IBM
//
// WebSphere Commerce
//
// (C) Copyright IBM Corp. 2016 All Rights Reserved.
//
// US Government Users Restricted Rights - Use, duplication or
// disclosure restricted by GSA ADP Schedule Contract with
// IBM Corp.
//-----------------------------------------------------------------

module.exports = function( grunt ) {
	"use strict";

	grunt.initConfig( {
		pkg: grunt.file.readJSON( "package.json" ),

		// --------------- Destination -----------------------
		vendorSourceDir: "../bower_components",
		webContentDir: "../..",
		distDir: "<%= webContentDir %>/JQuery",
		wcSourceDir: "<%= distDir %>/wc",
		widgetsSourceDir: "<%= webContentDir %>/Widgets_801",
		vendorJsDistFileName: "vendor",
		widgetsJSDistFileName: "widgets",

		concat: {
			options: {
				separator: ';',
			},
			vendor: {
				src: [
					// jquery and jquery UI source
					"<%= vendorSourceDir %>/jquery/dist/jquery.js",
					"<%= vendorSourceDir %>/jquery-ui/jquery-ui.js",
					// owl carousel JS files
					"<%= vendorSourceDir %>/OwlCarousel/owl-carousel/owl.carousel.js",
					// globalize JS files
					"<%= vendorSourceDir %>/cldrjs/dist/cldr.js",
					"<%= vendorSourceDir %>/cldrjs/dist/cldr/event.js",
					"<%= vendorSourceDir %>/cldrjs/dist/cldr/supplemental.js",
					"<%= vendorSourceDir %>/globalize/dist/globalize.js",
					"<%= vendorSourceDir %>/globalize/dist/globalize/message.js",
					"<%= vendorSourceDir %>/globalize/dist/globalize/number.js",
					"<%= vendorSourceDir %>/globalize/dist/globalize/currency.js",
					"<%= vendorSourceDir %>/globalize/dist/globalize/date.js",
					// wc files
					"<%= wcSourceDir %>/analytics/GenericEventListener.js",
					"<%= wcSourceDir %>/**/*.js"
				],
				dest: "<%= distDir %>/<%= vendorJsDistFileName %>.uncompressed.js"
			},
			widgets: {
				// wc jquery extension
				src: [
					// widget files
					"<%= widgetsSourceDir %>/**/*.js",
					"!<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.js",
					"!<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.uncompressed.js",
					"!<%= widgetsSourceDir %>/Common/javascript/homepage_widgets.js",
					"!<%= widgetsSourceDir %>/Common/javascript/homepage_widgets.uncompressed.js",
					"!<%= widgetsSourceDir %>/Common/javascript/ApplePay.js"
				],
				dest: "<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.uncompressed.js"				 
			}
		},

		copy: {
			dev: {
				files: [
					{
						// vendor.js
						src: "<%= distDir %>/<%= vendorJsDistFileName %>.uncompressed.js",
						dest: "<%= distDir %>/<%= vendorJsDistFileName %>.js"
					},
					{
						// widgets.js
						src: "<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.uncompressed.js",
						dest: "<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.js"
					}
				]
			}
		},

		clean: {
			files: [
				"<%= distDir %>/<%= vendorJsDistFileName %>.uncompressed.js",
				"<%= distDir %>/<%= vendorJsDistFileName %>.js",
				"<%= distDir %>/<%= vendorJsDistFileName %>.map",
				"<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.uncompressed.js",
				"<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.js",
				"<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.map"
			],
			options: {
				force: true
			}
		},

		watch: {
			vendor: {
				files: [ "<%= concat.vendor.src %>" ],
				tasks: [ "concat:vendor", "copy:dev" ]
			},
			widgets: {
				files: [ "<%= concat.widgets.src %>" ],
				tasks: [ "concat:widgets", "copy:dev" ]
			}
		},

		uglify: {
			vendor: {
				files: {
					"<%= distDir %>/<%= vendorJsDistFileName %>.js":
						"<%= distDir %>/<%= vendorJsDistFileName %>.uncompressed.js"
				},
				options: {
					preserveComments: false,
					sourceMap: true,
					sourceMapName:
						"<%= distDir %>/<%= vendorJsDistFileName %>.map",
					report: "min",
					beautify: {
						"ascii_only": true
					},
					compress: {
						"hoist_funs": false,
						loops: false,
						unused: false
					}
				}
			},
			widgets: {
				files: {
					"<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.js":
						"<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.uncompressed.js"
				},
				options: {
					preserveComments: false,
					sourceMap: true,
					sourceMapName:
						"<%= widgetsSourceDir %>/Common/javascript/<%= widgetsJSDistFileName %>.map",
					report: "min",
					beautify: {
						"ascii_only": true
					},
					compress: {
						"hoist_funs": false,
						loops: false,
						unused: false
					}
				}
			}
		}
	} );

	// Integrate jQuery specific tasks
	grunt.loadNpmTasks('grunt-contrib-copy');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-clean');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-contrib-watch');

	// Short list as a high frequency watch task
	grunt.registerTask( "dev", [ "clean", "concat", "copy:dev" ] );

	//grunt.registerTask( "prod", [ "clean", "build:*:*", "uglify", "remove_map_comment", "dist:*" ] );
	grunt.registerTask( "prod", [ "clean", "concat", "uglify" ] );

	// default option
	grunt.registerTask( "default", [ "dev", "watch" ] );
};
