//-----------------------------------------------------------------
// Licensed Materials - Property of IBM
//
// WebSphere Commerce
//
// (C) Copyright IBM Corp. 2016 All Rights Reserved.
//
// US Government Users Restricted Rights - Use, duplication or
// disclosure restricted by GSA ADP Schedule Contract with
// IBM Corp.
//-----------------------------------------------------------------

module.exports = function( grunt ) {
	"use strict";

	grunt.initConfig( {
		pkg: grunt.file.readJSON( "package.json" ),

		// --------------- Destination -----------------------
		vendorSourceDir: "../bower_components",
		webContentDir: "../..",
		storeSourceDir: "<%= webContentDir %>/<%= grunt.option('storename') %>",
		distDir: "<%= storeSourceDir %>/javascript",
		storeJsDistFileName: "store",
		properties: {
			gruntProps: 'grunt.properties'
		},

		concat: {
			options: {
				separator: ';',
			},
			storejs: {
				src: [
					// store JS files
					"<%= storeSourceDir %>/**/*.js",
					"!<%= distDir %>/<%= storeJsDistFileName %>.js",
					"!<%= distDir %>/<%= storeJsDistFileName %>.min.js",
					"!<%= distDir %>/<%= storeJsDistFileName %>.uncompressed.js",
					"!<%= distDir %>/homepage_store.js",
					"!<%= distDir %>/homepage_store.min.js",
					"!<%= distDir %>/homepage_store.uncompressed.js",
					"!<%= distDir %>/custom.js",
					"!<%= distDir %>/custom.min.js",
					"!<%= distDir %>/custom.uncompressed.js",
					"!<%= storeSourceDir %>/nls/**/*.js",
					"!<%= storeSourceDir %>/mobile30/**/*.js",
					"!<%= storeSourceDir %>/WorklightHybrid/**/*.js",
					"!<%= storeSourceDir %>/javascript/Tealeaf/**/*.js",
					"!<%= storeSourceDir %>/javascript/FBintegration.js"
				],
				dest: "<%= distDir %>/<%= storeJsDistFileName %>.uncompressed.js"
			},
			custom: {
				src: ["<%= gruntProps.myWidgetsDir %>/**/*.js"],
				dest: "<%= distDir %>/custom.uncompressed.js"
			},
			storecss: {
				src: [
					// store css files
					"<%= storeSourceDir %>/css/base.css",
					"<%= storeSourceDir %>/css/styles.css"
				],
				dest: "<%= storeSourceDir %>/css/<%= storeJsDistFileName %>.uncompressed.css"
			},
			vendorcss: {
				src: [
					"<%= vendorSourceDir %>/OwlCarousel/owl-carousel/owl.carousel.css",
					"<%= vendorSourceDir %>/jquery-mobile/css/structure/jquery.mobile.grid.css",
					"<%= vendorSourceDir %>/jquery-mobile/css/structure/jquery.mobile.grid.extended.css"
				],
				dest: "<%= storeSourceDir %>/css/vendor.uncompressed.css"
			}
		},

		copy: {
			devStore: {
				files: [
					{
						// store.js
						src: "<%= distDir %>/<%= storeJsDistFileName %>.uncompressed.js",
						dest: "<%= distDir %>/<%= storeJsDistFileName %>.js"
					},
					{
						// custom.js 
						src: "<%= distDir %>/custom.uncompressed.js",
						dest: "<%= distDir %>/custom.js"
					},
					{
						// from owl carousel
						src: "<%= vendorSourceDir %>/OwlCarousel/owl-carousel/grabbing.png",
						dest: "<%= storeSourceDir %>/css/grabbing.png"
					},
					{
						// store css
						src: "<%= storeSourceDir %>/css/<%= storeJsDistFileName %>.uncompressed.css",
						dest: "<%= storeSourceDir %>/css/<%= storeJsDistFileName %>.css"
					},
					{
						// vendor css
						src: "<%= storeSourceDir %>/css/vendor.uncompressed.css",
						dest: "<%= storeSourceDir %>/css/vendor.css"
					}
				]
			},
			
			prod: {
				files: [
					{
						// from owl carousel
						src: "<%= vendorSourceDir %>/OwlCarousel/owl-carousel/grabbing.png",
						dest: "<%= storeSourceDir %>/css/grabbing.png"
					}
				]
			}
		},

		clean: {
			files: [
				"<%= distDir %>/<%= storeJsDistFileName %>.uncompressed.js",
				"<%= distDir %>/<%= storeJsDistFileName %>.js",
				"<%= distDir %>/<%= storeJsDistFileName %>.map",
				"<%= storeSourceDir %>/css/<%= storeJsDistFileName %>.uncompressed.css",
				"<%= storeSourceDir %>/css/<%= storeJsDistFileName %>.css",
				"<%= storeSourceDir %>/css/vendor.uncompressed.css",
				"<%= storeSourceDir %>/css/vendor.css",
				"<%= distDir %>/custom.uncompressed.js",
				"<%= distDir %>/custom.js",
				"<%= distDir %>/custom.map"
			],
			options: {
				force: true
			}
		},

		watch: {
			storejs: {
				files: [ "<%= concat.storejs.src %>" ],
				tasks: [ "concat:storejs", "copy:devStore" ]
			},
			storecss: {
				files: [ "<%= concat.storecss.src %>" ],
				tasks: [ "concat:storecss", "copy:devStore" ]
			},
			custom: {
				files: [ "<%= gruntProps.myWidgetsDir %>/**/*.js" ],
				tasks: [ "concat:custom", "copy:devStore"]
			},
			vendorcss: {
				files: [ "<%= concat.vendorcss.src %>" ],
				tasks: [ "concat:storecss", "copy:devStore" ]
			}
		},

		uglify: {
			storejs: {
				files: {
					"<%= distDir %>/<%= storeJsDistFileName %>.js":
					"<%= distDir %>/<%= storeJsDistFileName %>.uncompressed.js"
				},
				options: {
					preserveComments: false,
					sourceMap: true,
					sourceMapName:
						"<%= distDir %>/<%= storeJsDistFileName %>.map",
					report: "min",
					beautify: {
						"ascii_only": true
					},
					compress: {
						"hoist_funs": false,
						loops: false,
						unused: false
					}
				}
			},
			custom: {
				files: {
					"<%= distDir %>/custom.js":
					"<%= distDir %>/custom.uncompressed.js"
				},
				options: {
					preserveComments: false,
					sourceMap: true,
					sourceMapName:
						"<%= distDir %>/custom.map",
					report: "min",
					beautify: {
						"ascii_only": true
					},
					compress: {
						"hoist_funs": false,
						loops: false,
						unused: false
					}
				}
			}
		},
		
		cssmin: {
			options: {
				shorthandCompacting: false,
				roundingPrecision: -1
			},
			target: {
				files: [
					{
						"<%= storeSourceDir %>/css/vendor.css": 
						["<%= storeSourceDir %>/css/vendor.uncompressed.css"]
					},
					{
						"<%= storeSourceDir %>/css/<%= storeJsDistFileName %>.css": 
						["<%= storeSourceDir %>/css/<%= storeJsDistFileName %>.uncompressed.css"]
					}
				]
			}
		}
	} );

	// Integrate jQuery specific tasks
	grunt.loadNpmTasks('grunt-contrib-copy');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-clean');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-contrib-watch');
	grunt.loadNpmTasks('grunt-contrib-cssmin');
	grunt.loadNpmTasks('grunt-properties-reader');

	// Check if storename is provided
	grunt.registerTask( "check_store", function() {
		// make sure storename param exists
		if ( grunt.option( "storename" ) == null ) {
			grunt.fail.fatal( "storename param is mandatory", [ 3 ] );
		}
		
		var path = __dirname + "/../../" + grunt.option( "storename" );
		if (!grunt.file.exists(path)) {
			grunt.fail.fatal( "cannot find directory: " + path, [ 3 ] );
		}
	} );
	
	// Short list as a high frequency watch task
	grunt.registerTask( "dev", [ "properties", "check_store", "clean", "concat", "copy:devStore" ] );

	//grunt.registerTask( "prod", [ "clean", "build:*:*", "uglify", "remove_map_comment", "dist:*" ] );
	grunt.registerTask( "prod", [ "properties", "check_store", "clean", "concat", "uglify", "cssmin", "copy:prod" ] );

	// default option
	grunt.registerTask( "default", [ "dev", "watch" ] );
};
